import BigNumber from 'bignumber.js';
export interface FeeWindow {
    address: string;
    balance: BigNumber;
    totalFeeStake: BigNumber;
    endTime: Date;
}
interface ParticipationRentabilityResult {
    gasCost: BigNumber;
    totalFeeProfit: BigNumber;
    totalProfit: BigNumber;
    profitPerRep: BigNumber;
    profitPercent: BigNumber;
    profitPercentPA: BigNumber;
    numRepBreakEven: BigNumber;
    gasPriceBreakEven: BigNumber;
    numRepMaxProfitPerRep: BigNumber;
}
export default class AugurFeeWindow {
    private web3;
    constructor(web3?: any);
    setWeb3(web3: any): void;
    /**
     *
     * @returns {number} - Gas price in ETH
     */
    getGasPrice(): Promise<BigNumber>;
    /**
     *
     * @returns {BigNumber} - REP price in ETH
     */
    getRepEthPrice(): Promise<BigNumber>;
    /**
     *
     * @returns {Promise<FeeWindow>} - The current fee window info
     */
    getCurrentFeeWindow(): Promise<FeeWindow>;
    /**
     *
     * @returns {Promise<FeeWindow>} - The next fee window info
     */
    getNextFeeWindow(): Promise<FeeWindow>;
    /**
     * Caution: this method needs a lot of requests and therefore may be slow
     * @returns {Promise<FeeWindow>} - The previous fee window info
     */
    getPreviousFeeWindow(): Promise<FeeWindow>;
    /**
     * Calculates some profit values for the given input parameter
     * @param {BigNumber} fees - The fees in the fee window in ETH
     * @param {BigNumber} gasPrice - The gas price in ETH
     * @param {BigNumber} gasUsed - The used gas for both transactions (buying participation tokens and redeeming)
     * @param {BigNumber} rep - The number of used REP
     * @param {BigNumber} repEthPrice the REP-ETH price
     * @param {BigNumber} stake the stake in the fee window in REP
     * @returns {ParticipationRentabilityResult}
     */
    calculateParticipationRentability(fees: BigNumber, gasPrice: BigNumber, gasUsed: BigNumber, rep: BigNumber, repEthPrice: BigNumber, stake: BigNumber): ParticipationRentabilityResult;
    /**
     * Caution: If the fee window is over this method needs a lot of requests and therefore may be slow.
     * @param {string} address The address of the fee window to get
     * @param {boolean} isOver True, iff the fee window is over
     * @returns {Promise<FeeWindow>}
     */
    getFeeWindow(address: string, isOver?: boolean): Promise<FeeWindow>;
    private cashContract;
    private universeContract;
    /**
     * Binary searching a block number
     * @param {number} target timestamp
     * @param {number} lowerBound timestamp
     * @param {number} upperBound timestamp
     * @param {number} numBlocks the number of blocks to step back if the lower bound is still to high
     * @returns {Promise<number>} The last block which was before or exactly at the time given by target
     */
    private binarySearch;
}
export {};
